package com.ekexiu.project.platform.system.dao;

import java.sql.Connection;
import java.sql.SQLException;

import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.orm.annotation.dao.Batch;
import org.jfw.apt.orm.annotation.dao.DAO;
import org.jfw.apt.orm.annotation.dao.method.Exclude;
import org.jfw.apt.orm.annotation.dao.method.From;
import org.jfw.apt.orm.annotation.dao.method.IncludeFixSet;
import org.jfw.apt.orm.annotation.dao.method.SetSentence;
import org.jfw.apt.orm.annotation.dao.method.Where;
import org.jfw.apt.orm.annotation.dao.method.operator.DeleteWith;
import org.jfw.apt.orm.annotation.dao.method.operator.Insert;
import org.jfw.apt.orm.annotation.dao.method.operator.SelectOne;
import org.jfw.apt.orm.annotation.dao.method.operator.Update;
import org.jfw.apt.orm.annotation.dao.method.operator.UpdateWith;
import org.jfw.apt.orm.annotation.dao.param.Alias;
import org.jfw.apt.orm.annotation.dao.param.Set;
import org.jfw.apt.orm.annotation.dao.param.UnEquals;

import com.ekexiu.project.platform.system.po.Manager;
import com.ekexiu.project.platform.system.po.SysRight;
import com.ekexiu.project.platform.system.po.User;
import com.ekexiu.project.platform.system.po.UserLoginLog;


@DAO
public interface UserDao {

	@Nullable
	@SelectOne
	User query(Connection con, String id) throws SQLException;

	@Nullable
	@SelectOne
	User queryByLoginPhone(Connection con,String loginPhone,Boolean active) throws SQLException;
	
	@Nullable
	@SelectOne
	User login(Connection con, String account, String passwd) throws SQLException;
	
	@Insert
	int insert(Connection con, User user) throws SQLException;
	
	@Insert
	int insert(Connection con,UserLoginLog uli)throws SQLException;
	
	@UpdateWith
	@From(UserLoginLog.class)
	int updateLoginLog(Connection con,String id,@Set String lastLoginTime)throws SQLException;

	@Update
	@Exclude({"passwd","active","loginPhone"})
	int update(Connection con, User user) throws SQLException;
	
	@UpdateWith
	@From(User.class)
	int changePasswd(Connection con,String id,String passwd,@Set @Alias("passwd") String newPasswd) throws SQLException;
	
	@UpdateWith
	@From(User.class)
	int resetPasswd(Connection con,String loginPhone,@Set String passwd) throws SQLException;
	
	
	
	@Insert
	int insert(Connection con,Manager user)throws SQLException;
	
	@Insert
	@Batch
	int[] insert(Connection con,SysRight[] rightcodes)throws SQLException;
	
	@DeleteWith
	@From(SysRight.class)
	int delete(Connection con,String uid,@UnEquals String rightCode)throws SQLException;
	
	
	@Update
	@Where("ACTIVE ='1'")
	@IncludeFixSet
	@Exclude(value = { "invalidTime","invalidOperator","passwd","active" })
	int update(Connection con,Manager user)throws SQLException;
	
	@UpdateWith
	@From(Manager.class)
	@Where("ACTIVE ='1'")
	@SetSentence("ACTIVE='0',INVALID_TIME=TO_CHAR(NOW(),'YYYYMMDDHH24MISS')")
	int disable(Connection con,String id,@Set String invalidOperator)throws SQLException;
	
	@UpdateWith
	@From(Manager.class)
	@Where("ACTIVE ='0'")
	@SetSentence("ACTIVE='1'")
	int disable(Connection con,String id)throws SQLException;
	
	
	
}
